"""Add labels to conversations

Reason:
This migration adds a new table, "conversation_label", which allows Rasa X to
store arbitrary text labels for conversations.

Revision ID: 924e47e0a9e5
Revises: 3b15f8e56784

"""
from alembic import op
import sqlalchemy as sa


# revision identifiers, used by Alembic.
revision = "924e47e0a9e5"
down_revision = "3b15f8e56784"
branch_labels = None
depends_on = None

INDEX_NAME = "conversation_label_value"


def upgrade():
    op.create_table(
        "conversation_label",
        sa.Column("id", sa.Integer(), nullable=False),
        sa.Column("conversation_id", sa.String(255), nullable=False),
        sa.Column("value", sa.String(255), nullable=False),
        sa.ForeignKeyConstraint(["conversation_id"], ["conversation.sender_id"]),
        sa.PrimaryKeyConstraint("id"),
    )

    with op.batch_alter_table("conversation_label") as batch_op:
        batch_op.create_index(INDEX_NAME, ["value"])


def downgrade():
    with op.batch_alter_table("conversation_label") as batch_op:
        batch_op.drop_index(INDEX_NAME)

    op.drop_table("conversation_label")
